@@ -1,28 +1,32 @@
-# Copyright (C) 2010 Richard Lincoln
+# Copyright (C) 2010-2011 Richard Lincoln
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to
+# deal in the Software without restriction, including without limitation the
+# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+# sell copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+# IN THE SOFTWARE.
 
 """The IEC 61968 subpackages of the CIM are developed, standardized and maintained by IEC TC57 Working Group 14: System Interfaces for Distribution Management (WG14). Currently, normative parts of the model support the needs of information exchange defined in IEC 61968-9: 'Interfaces for Meter Reading and Control' and in IEC 61968-13: 'CIM RDF Model exchange format for distribution.'
 """
 
-nsPrefix = "cim"
-nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14"
-
 from CIM14.CombinedVersion import CombinedVersion
 from CIM14.Element import Element
 
+nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14"
+nsPrefix = "cim"
+
 packageMap = {
     "CombinedVersion": "CIM14",
     "Element": "CIM14",
@@ -242,6 +246,153 @@ packageMap = {
     "ModelingAuthoritySet": "CIM14.IEC61970.Informative.InfCore",
     "TopologicalNode": "CIM14.IEC61970.Topology",
     "BusNameMarker": "CIM14.IEC61970.Topology",
+    "BlockConnection": "CIM14.IEC61970.Dynamics",
+    "RotatingMachine": "CIM14.IEC61970.Dynamics",
+    "AsynchronousMachine": "CIM14.IEC61970.Dynamics",
+    "BlockUsageInputReference": "CIM14.IEC61970.Dynamics",
+    "MetaBlockConnectable": "CIM14.IEC61970.Dynamics",
+    "MetaBlockOutput": "CIM14.IEC61970.Dynamics",
+    "MetaBlockConOutput": "CIM14.IEC61970.Dynamics",
+    "MetaBlock": "CIM14.IEC61970.Dynamics",
+    "MetaBlockInput": "CIM14.IEC61970.Dynamics",
+    "SlotReference": "CIM14.IEC61970.Dynamics",
+    "MetaBlockInputReference": "CIM14.IEC61970.Dynamics",
+    "MetaBlockParameter": "CIM14.IEC61970.Dynamics",
+    "MetaBlockParameterReference": "CIM14.IEC61970.Dynamics",
+    "CompositeModel": "CIM14.IEC61970.Dynamics",
+    "BlockInputType": "CIM14.IEC61970.Dynamics",
+    "BlockConnectivity": "CIM14.IEC61970.Dynamics",
+    "SlotInput": "CIM14.IEC61970.Dynamics",
+    "MetaBlockSignal": "CIM14.IEC61970.Dynamics",
+    "MetaBlockStateReference": "CIM14.IEC61970.Dynamics",
+    "BlockConstant": "CIM14.IEC61970.Dynamics",
+    "SourceModels": "CIM14.IEC61970.Dynamics",
+    "SlotConnection": "CIM14.IEC61970.Dynamics",
+    "Block": "CIM14.IEC61970.Dynamics",
+    "ConnectionFrame": "CIM14.IEC61970.Dynamics",
+    "MetaBlockConInput": "CIM14.IEC61970.Dynamics",
+    "StaticVarDevice": "CIM14.IEC61970.Dynamics",
+    "AttributeBlockParameter": "CIM14.IEC61970.Dynamics",
+    "UserBlockParameter": "CIM14.IEC61970.Dynamics",
+    "MetaBlockConnection": "CIM14.IEC61970.Dynamics",
+    "Slot": "CIM14.IEC61970.Dynamics",
+    "MetaBlockReference": "CIM14.IEC61970.Dynamics",
+    "BlockInputReference": "CIM14.IEC61970.Dynamics",
+    "BlockParameter": "CIM14.IEC61970.Dynamics",
+    "MetaBlockConSignal": "CIM14.IEC61970.Dynamics",
+    "BlockOutputReference": "CIM14.IEC61970.Dynamics",
+    "ExcitationSystemLimiter": "CIM14.IEC61970.Dynamics",
+    "BlockType": "CIM14.IEC61970.Dynamics",
+    "SlotOutput": "CIM14.IEC61970.Dynamics",
+    "ProtectiveDevice": "CIM14.IEC61970.Dynamics",
+    "MetaBlockState": "CIM14.IEC61970.Dynamics",
+    "BlockUsageOutputReference": "CIM14.IEC61970.Dynamics",
+    "TieToMeasurement": "CIM14.IEC61970.Dynamics",
+    "MetaBlockConnectivity": "CIM14.IEC61970.Dynamics",
+    "MetaBlockOutputReference": "CIM14.IEC61970.Dynamics",
+    "BlockOutputType": "CIM14.IEC61970.Dynamics",
+    "MechanicalLoad": "CIM14.IEC61970.Dynamics.Motors",
+    "MotorSync": "CIM14.IEC61970.Dynamics.Motors",
+    "MechLoad1": "CIM14.IEC61970.Dynamics.Motors",
+    "MotorAsync": "CIM14.IEC61970.Dynamics.Motors",
+    "ExcitationSystem": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcDC4B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC1A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcSEXS": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC6A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcDC3A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcBBC": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST7B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcSCRX": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC5A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcREXS": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcELIN1": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST3A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcSK2": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcPIC": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST5B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcCZ": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST1A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcDC1A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC3A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC4A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC2A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcWT2E": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcDC2A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC8B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST2A": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcHU": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcBAS": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcSK": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcWT3E": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST6B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcELIN2": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcST4B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcAC7B": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "ExcWT4E": "CIM14.IEC61970.Dynamics.ExcitationSystems",
+    "TurbineGovernor": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteamFV2": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT3P": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteamSGO": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovGASM": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydroR": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT4T": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovGAST2": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteamCC": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovRAV": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteam1": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "TLCFB1": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydro4": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovCT2": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydro1": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovGAST": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT3T": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydroWPID": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT1T": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT2T": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "Class1": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT4P": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydroPID": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydroWEH": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydroDD": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT1P": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovWT2P": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteamEU": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydro3": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteam0": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydroPID2": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydro2": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovCT1": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovHydro0": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovGASTWD": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovSteamFV3": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GovDUM": "CIM14.IEC61970.Dynamics.TurbineGovernors",
+    "GenLoad": "CIM14.IEC61970.Dynamics.Generators",
+    "GenEquiv": "CIM14.IEC61970.Dynamics.Generators",
+    "GenAsync": "CIM14.IEC61970.Dynamics.Generators",
+    "PowerSystemStabilizer": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssIEEE3B": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssSK": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssIEEE4B": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssIEEE1A": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssPTIST1": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssIEEE2B": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssSB": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssSB4": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssSH": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssPTIST3": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "PssWSCC": "CIM14.IEC61970.Dynamics.PowerSystemStabilizers",
+    "AggregateLoad": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadStatic": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadStaticSystem": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadStaticOwner": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadStaticZone": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadStaticBus": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadStaticArea": "CIM14.IEC61970.Dynamics.Loads",
+    "LoadMotor": "CIM14.IEC61970.Dynamics.Loads",
+    "VoltageCompensator": "CIM14.IEC61970.Dynamics.VoltageCompensator",
+    "VcompCross": "CIM14.IEC61970.Dynamics.VoltageCompensator",
+    "VcompIEEE": "CIM14.IEC61970.Dynamics.VoltageCompensator",
     "IEC61968CIMVersion": "CIM14.IEC61968",
     "AssetFunction": "CIM14.IEC61968.Assets",
     "Asset": "CIM14.IEC61968.Assets",
@@ -348,151 +499,5 @@ packageMap = {
     "Work": "CIM14.IEC61968.Work",
     "RemoteConnectDisconnectInfo": "CIM14.IEC61968.LoadControl",
     "ConnectDisconnectFunction": "CIM14.IEC61968.LoadControl",
-    "BlockConnection": "CIM14.Dynamics",
-    "RotatingMachine": "CIM14.Dynamics",
-    "AsynchronousMachine": "CIM14.Dynamics",
-    "BlockUsageInputReference": "CIM14.Dynamics",
-    "MetaBlockConnectable": "CIM14.Dynamics",
-    "MetaBlockOutput": "CIM14.Dynamics",
-    "MetaBlockConOutput": "CIM14.Dynamics",
-    "MetaBlock": "CIM14.Dynamics",
-    "MetaBlockInput": "CIM14.Dynamics",
-    "SlotReference": "CIM14.Dynamics",
-    "MetaBlockInputReference": "CIM14.Dynamics",
-    "MetaBlockParameter": "CIM14.Dynamics",
-    "MetaBlockParameterReference": "CIM14.Dynamics",
-    "CompositeModel": "CIM14.Dynamics",
-    "BlockInputType": "CIM14.Dynamics",
-    "BlockConnectivity": "CIM14.Dynamics",
-    "SlotInput": "CIM14.Dynamics",
-    "MetaBlockSignal": "CIM14.Dynamics",
-    "MetaBlockStateReference": "CIM14.Dynamics",
-    "BlockConstant": "CIM14.Dynamics",
-    "SourceModels": "CIM14.Dynamics",
-    "SlotConnection": "CIM14.Dynamics",
-    "Block": "CIM14.Dynamics",
-    "ConnectionFrame": "CIM14.Dynamics",
-    "MetaBlockConInput": "CIM14.Dynamics",
-    "StaticVarDevice": "CIM14.Dynamics",
-    "AttributeBlockParameter": "CIM14.Dynamics",
-    "UserBlockParameter": "CIM14.Dynamics",
-    "MetaBlockConnection": "CIM14.Dynamics",
-    "Slot": "CIM14.Dynamics",
-    "MetaBlockReference": "CIM14.Dynamics",
-    "BlockInputReference": "CIM14.Dynamics",
-    "BlockParameter": "CIM14.Dynamics",
-    "MetaBlockConSignal": "CIM14.Dynamics",
-    "BlockOutputReference": "CIM14.Dynamics",
-    "ExcitationSystemLimiter": "CIM14.Dynamics",
-    "BlockType": "CIM14.Dynamics",
-    "SlotOutput": "CIM14.Dynamics",
-    "ProtectiveDevice": "CIM14.Dynamics",
-    "MetaBlockState": "CIM14.Dynamics",
-    "BlockUsageOutputReference": "CIM14.Dynamics",
-    "TieToMeasurement": "CIM14.Dynamics",
-    "MetaBlockConnectivity": "CIM14.Dynamics",
-    "MetaBlockOutputReference": "CIM14.Dynamics",
-    "BlockOutputType": "CIM14.Dynamics",
-    "MechanicalLoad": "CIM14.Dynamics.Motors",
-    "MotorSync": "CIM14.Dynamics.Motors",
-    "MechLoad1": "CIM14.Dynamics.Motors",
-    "MotorAsync": "CIM14.Dynamics.Motors",
-    "ExcitationSystem": "CIM14.Dynamics.ExcitationSystems",
-    "ExcDC4B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC1A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcSEXS": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC6A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcDC3A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcBBC": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST7B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcSCRX": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC5A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcREXS": "CIM14.Dynamics.ExcitationSystems",
-    "ExcELIN1": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST3A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcSK2": "CIM14.Dynamics.ExcitationSystems",
-    "ExcPIC": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST5B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcCZ": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST1A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcDC1A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC3A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC4A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC2A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcWT2E": "CIM14.Dynamics.ExcitationSystems",
-    "ExcDC2A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC8B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST2A": "CIM14.Dynamics.ExcitationSystems",
-    "ExcHU": "CIM14.Dynamics.ExcitationSystems",
-    "ExcBAS": "CIM14.Dynamics.ExcitationSystems",
-    "ExcSK": "CIM14.Dynamics.ExcitationSystems",
-    "ExcWT3E": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST6B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcELIN2": "CIM14.Dynamics.ExcitationSystems",
-    "ExcST4B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcAC7B": "CIM14.Dynamics.ExcitationSystems",
-    "ExcWT4E": "CIM14.Dynamics.ExcitationSystems",
-    "TurbineGovernor": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteamFV2": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT3P": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteamSGO": "CIM14.Dynamics.TurbineGovernors",
-    "GovGASM": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydroR": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT4T": "CIM14.Dynamics.TurbineGovernors",
-    "GovGAST2": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteamCC": "CIM14.Dynamics.TurbineGovernors",
-    "GovRAV": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteam1": "CIM14.Dynamics.TurbineGovernors",
-    "TLCFB1": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydro4": "CIM14.Dynamics.TurbineGovernors",
-    "GovCT2": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydro1": "CIM14.Dynamics.TurbineGovernors",
-    "GovGAST": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT3T": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydroWPID": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT1T": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT2T": "CIM14.Dynamics.TurbineGovernors",
-    "Class1": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT4P": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydroPID": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydroWEH": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydroDD": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT1P": "CIM14.Dynamics.TurbineGovernors",
-    "GovWT2P": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteamEU": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydro3": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteam0": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydroPID2": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydro2": "CIM14.Dynamics.TurbineGovernors",
-    "GovCT1": "CIM14.Dynamics.TurbineGovernors",
-    "GovHydro0": "CIM14.Dynamics.TurbineGovernors",
-    "GovGASTWD": "CIM14.Dynamics.TurbineGovernors",
-    "GovSteamFV3": "CIM14.Dynamics.TurbineGovernors",
-    "GovDUM": "CIM14.Dynamics.TurbineGovernors",
-    "GenLoad": "CIM14.Dynamics.Generators",
-    "GenEquiv": "CIM14.Dynamics.Generators",
-    "GenAsync": "CIM14.Dynamics.Generators",
-    "PowerSystemStabilizer": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssIEEE3B": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssSK": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssIEEE4B": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssIEEE1A": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssPTIST1": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssIEEE2B": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssSB": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssSB4": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssSH": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssPTIST3": "CIM14.Dynamics.PowerSystemStabilizers",
-    "PssWSCC": "CIM14.Dynamics.PowerSystemStabilizers",
-    "AggregateLoad": "CIM14.Dynamics.Loads",
-    "LoadStatic": "CIM14.Dynamics.Loads",
-    "LoadStaticSystem": "CIM14.Dynamics.Loads",
-    "LoadStaticOwner": "CIM14.Dynamics.Loads",
-    "LoadStaticZone": "CIM14.Dynamics.Loads",
-    "LoadStaticBus": "CIM14.Dynamics.Loads",
-    "LoadStaticArea": "CIM14.Dynamics.Loads",
-    "LoadMotor": "CIM14.Dynamics.Loads",
-    "VoltageCompensator": "CIM14.Dynamics.VoltageCompensator",
-    "VcompCross": "CIM14.Dynamics.VoltageCompensator",
-    "VcompIEEE": "CIM14.Dynamics.VoltageCompensator",
 }
+
